@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -145,8 +145,8 @@ void SpecialNotifierJob::emitNotification(const QPixmap &pixmap)
     if (NewMailNotifierAgentSettings::textToSpeakEnabled()) {
         if (!NewMailNotifierAgentSettings::textToSpeak().isEmpty()) {
             QString message = NewMailNotifierAgentSettings::textToSpeak();
-            message.replace(QStringLiteral("%s"), mSubject.toHtmlEscaped());
-            message.replace(QStringLiteral("%f"), mFrom.toHtmlEscaped());
+            message.replace(QLatin1String("%s"), mSubject.toHtmlEscaped());
+            message.replace(QLatin1String("%f"), mFrom.toHtmlEscaped());
             Q_EMIT say(message);
         }
     }
